@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -16,7 +14,6 @@
 
 import collections
 
-from debtcollector import removals
 import prettytable
 import six
 
@@ -104,16 +101,10 @@ class FiniteMachine(object):
         return cls.Effect(new_state['reactions'].get(event),
                           new_state["terminal"])
 
-    @removals.removed_kwarg('default_start_state',
-                            message="The usage of 'default_start_state' via"
-                            " the machine constructor is deprecated and will"
-                            " be removed in a future version; usage of"
-                            " the 'default_start_state' property setter is"
-                            " recommended.")
-    def __init__(self, default_start_state=None):
+    def __init__(self):
         self._transitions = {}
         self._states = collections.OrderedDict()
-        self._default_start_state = default_start_state
+        self._default_start_state = None
         self._current = None
         self.frozen = False
 
@@ -153,7 +144,7 @@ class FiniteMachine(object):
                         on_exit=state.on_exit)
         for state in state_space:
             if state.next_states:
-                for event, next_state in six.iteritems(state.next_states):
+                for event, next_state in state.next_states.items():
                     if isinstance(next_state, State):
                         next_state = next_state.name
                     m.add_transition(state.name, next_state, event)
@@ -367,11 +358,11 @@ class FiniteMachine(object):
         else:
             c.frozen = self.frozen
         if not shallow:
-            for state, data in six.iteritems(self._states):
+            for state, data in self._states.items():
                 copied_data = data.copy()
                 copied_data['reactions'] = copied_data['reactions'].copy()
                 c._states[state] = copied_data
-            for state, data in six.iteritems(self._transitions):
+            for state, data in self._transitions.items():
                 c._transitions[state] = data.copy()
         else:
             c._transitions = self._transitions
@@ -402,7 +393,7 @@ class FiniteMachine(object):
     def __iter__(self):
         """Iterates over (start, event, end) transition tuples."""
         for state in six.iterkeys(self._states):
-            for event, target in six.iteritems(self._transitions[state]):
+            for event, target in self._transitions[state].items():
                 yield (state, event, target.name)
 
     def pformat(self, sort=True, empty='.'):
@@ -462,9 +453,8 @@ class HierarchicalFiniteMachine(FiniteMachine):
     Effect = collections.namedtuple('Effect',
                                     'reaction,terminal,machine')
 
-    def __init__(self, default_start_state=None):
-        super(HierarchicalFiniteMachine, self).__init__(
-            default_start_state=default_start_state)
+    def __init__(self):
+        super(HierarchicalFiniteMachine, self).__init__()
         self._nested_machines = {}
 
     @classmethod
